<?php
/**
 * Dellow functions and definitions
 *
 * @package Dellow
 */
if ( ! function_exists( 'dellow_setup' ) ) :

    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function dellow_setup() {

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        //Guttenberg fullscreen content
        add_theme_support( 'align-wide' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         *
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
         */
        add_theme_support( 'automatic-feed-links' );
        add_theme_support( 'post-thumbnails' );
        add_image_size('homepage-banner',400,400,true);
        add_image_size('dellow-pop-thumb',525,350,true);


        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => __( 'Primary Menu', 'dellow' ),
            'mobile' => __( 'Mobile Menu', 'dellow' ),
        ) );

        // Set up the WordPress core custom background feature.
        add_theme_support( 'custom-background', apply_filters( 'dellow_custom_background_args', array(
            'default-color' => 'eeeeee',
            'default-image' => '',
        ) ) );

        /**
         * Set the content width based on the theme's design and stylesheet.
         */
        global $content_width;
        if ( ! isset( $content_width ) )
            $content_width = 640; /* pixels */

        /*
         * Enable support for RT Slider Plugin.
         */
        add_theme_support('rt-slider', array( 5 ));

        //Custom Logo
        add_theme_support( 'custom-logo', array(
            'flex-height' => true,
            'flex-width'  => true,
            'header-text' => array( 'site-title', 'site-description' ),
        ) );

    }
endif; // dellow_setup
add_action( 'after_setup_theme', 'dellow_setup' );
